<?php
/*
 * Funciones para migrar de metadato a tabla
 * Metadato a migrar: _keys
 * Tabla nueva: wp_waolm_dispatched_keys
 * ESTRUCTURA DE LA TABLA
 * ID|sku|product_name|customer_email|order_id|key|
*/

if( ! defined( 'ABSPATH' ) ) {
    exit;
}
// Crear la tabla wp_waolm_dispatched_keys si no existe
function create_waolm_dispatched_keys_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'waolm_dispatched_keys';
    $charset_collate = $wpdb->get_charset_collate();
    $sql = "CREATE TABLE IF NOT EXISTS $table_name (
        ID bigint(20) NOT NULL AUTO_INCREMENT,
        sku varchar(255) NOT NULL,
        product_name varchar(255) NOT NULL,
        customer_email varchar(255) NOT NULL,
        order_id bigint(20) NOT NULL,
        key varchar(255) NOT NULL,
        PRIMARY KEY (ID)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}
//add_action('init', 'create_waolm_dispatched_keys_table');

// Migrar de metadato _keys a tabla wp_waolm_dispatched_keys
function migrate_keys_to_new_table() {
    global $wpdb;

    // Verifica si la migración ya se ha realizado
    $migration_done = get_option('waolm_keys_migration_done');
    if ($migration_done) {
        return;
    }

    // Obtener todas las órdenes
    $orders = wc_get_orders(array('limit' => -1));
    $table_name = $wpdb->prefix . 'waolm_dispatched_keys';

    foreach ($orders as $order) {
        $order_id = $order->get_id();
        $keys_meta = get_post_meta($order_id, '_keys', true);

        if ($keys_meta) {
            foreach ($keys_meta as $key_data) {
                if (is_array($key_data)) {
                    foreach ($key_data as $key_object) {
                        if (is_object($key_object)) {
                            $sku = $key_object->product_sku;
                            $product_name = $key_object->productname;
                            $customer_email = $order->get_billing_email();
                            $key = $key_object->skey;

                            $wpdb->insert(
                                $table_name,
                                array(
                                    'sku' => $sku,
                                    'product_name' => $product_name,
                                    'customer_email' => $customer_email,
                                    'order_id' => $order_id,
                                    'key' => $key
                                ),
                                array(
                                    '%s',
                                    '%s',
                                    '%s',
                                    '%d',
                                    '%s'
                                )
                            );
                        }
                    }
                }
            }
        }
    }

    // Marcar la migración como completada
    update_option('waolm_keys_migration_done', 1);
}
//add_action('init', 'migrate_keys_to_new_table');

// Guardar las llaves en la nueva tabla a partir de ahora
function save_keys_to_new_table($order_id) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'waolm_dispatched_keys';
    $order = wc_get_order($order_id);
    $keys_meta = get_post_meta($order_id, '_keys', true);
    $customer_email = $order->get_billing_email();

    if ($keys_meta) {
        foreach ($keys_meta as $key_data) {
            if (is_array($key_data)) {
                foreach ($key_data as $key_object) {
                    if (is_object($key_object)) {
                        $sku = $key_object->product_sku;
                        $product_name = $key_object->productname;
                        $key = $key_object->skey;

                        $wpdb->insert(
                            $table_name,
                            array(
                                'sku' => $sku,
                                'product_name' => $product_name,
                                'customer_email' => $customer_email,
                                'order_id' => $order_id,
                                'key' => $key
                            ),
                            array(
                                '%s',
                                '%s',
                                '%s',
                                '%d',
                                '%s'
                            )
                        );
                    }
                }
            }
        }
    }
}

//add_action('woocommerce_order_status_completed', 'save_keys_to_new_table');

